Type | Syntax | Description
--- | --- | ---
Alignment | { top | bottom | left | right | center }* | To-Do
Background | { Brush | Alignment }* | To-Do
Border | { Border Style | Length | Brush }* | To-Do
Border Style | dashed | dot-dash | dot-dot-dash | dotted | double | groove | inset | outset | ridge | solid | none | To-Do
Box Colors | Brush{1, 4} | To-Do
Box Lengths | Length{1, 4} | To-Do
Brush | Color | Gradient | To-Do
Color | { rgb(r, g, b) | rgba(r, g, b, a) | hsv(h, s, v) | hsva(h, s, v, a) | #rrggbb | CSS Color Name }* | To-Do
Font | ( Font Style | Font Weight ){0, 2} Font Size String | To-Do
Font Size | Length | To-Do
Font Style | normal | italic | oblique | To-Do
Font Weight | normal | bold | 100 | 200 | ... | 900 | To-Do
Gradient | lineargradient | radialgradient | To-Do
Length | Number( px | pt | em | ex )? | To-Do
Number | integer | real | To-Do
Origin | margin | border | padding | content | To-Do
Radius | Length{1, 2} | To-Do